==> apache-arrow-datafusion-36.0.1.tar.gz: apache-arrow-datafusion-36.0.1/datafusion/expr/src/logical_plan/mod.rs <==
// Licensed to the Apache Software Foundation (ASF) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The ASF licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.

pub mod builder;
mod ddl;
pub mod display;
pub mod dml;
mod extension;
mod plan;
mod statement;

pub use builder::{
    build_join_schema, table_scan, union, wrap_projection_for_join_if_necessary,
    LogicalPlanBuilder, UNNAMED_TABLE,
};
pub use ddl::{
    CreateCatalog, CreateCatalogSchema, CreateExternalTable, CreateMemoryTable,
    CreateView, DdlStatement, DropCatalogSchema, DropTable, DropView,
};
pub use dml::{DmlStatement, WriteOp};
pub use plan::{
    projection_schema, Aggregate, Analyze, CrossJoin, DescribeTable, Distinct,
    DistinctOn, EmptyRelation, Explain, Extension, Filter, Join, JoinConstraint,
    JoinType, Limit, LogicalPlan, Partitioning, PlanType, Prepare, Projection,
    RecursiveQuery, Repartition, Sort, StringifiedPlan, Subquery, SubqueryAlias,
    TableScan, ToStringifiedPlan, Union, Unnest, Values, Window,
};
pub use statement::{
    SetVariable, Statement, TransactionAccessMode, TransactionConclusion, TransactionEnd,
    TransactionIsolationLevel, TransactionStart,
};

pub use display::display_schema;

pub use extension::{UserDefinedLogicalNode, UserDefinedLogicalNodeCore};

==> apache-arrow-datafusion-37.0.0.tar.gz: apache-arrow-datafusion-37.0.0/datafusion/expr/src/logical_plan/mod.rs <==
// Licensed to the Apache Software Foundation (ASF) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The ASF licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.

pub mod builder;
mod ddl;
pub mod display;
pub mod dml;
mod extension;
mod plan;
mod statement;

pub use builder::{
    build_join_schema, table_scan, union, wrap_projection_for_join_if_necessary,
    LogicalPlanBuilder, UNNAMED_TABLE,
};
pub use ddl::{
    CreateCatalog, CreateCatalogSchema, CreateExternalTable, CreateFunction,
    CreateFunctionBody, CreateMemoryTable, CreateView, DdlStatement, DefinitionStatement,
    DropCatalogSchema, DropFunction, DropTable, DropView, OperateFunctionArg,
};
pub use dml::{DmlStatement, WriteOp};
pub use plan::{
    projection_schema, Aggregate, Analyze, CrossJoin, DescribeTable, Distinct,
    DistinctOn, EmptyRelation, Explain, Extension, Filter, Join, JoinConstraint,
    JoinType, Limit, LogicalPlan, Partitioning, PlanType, Prepare, Projection,
    RecursiveQuery, Repartition, Sort, StringifiedPlan, Subquery, SubqueryAlias,
    TableScan, ToStringifiedPlan, Union, Unnest, Values, Window,
};
pub use statement::{
    SetVariable, Statement, TransactionAccessMode, TransactionConclusion, TransactionEnd,
    TransactionIsolationLevel, TransactionStart,
};

pub use display::display_schema;

pub use extension::{UserDefinedLogicalNode, UserDefinedLogicalNodeCore};
